{ Reader Engine for Excel (dll edition)
  demo project for Borland Delphi

  Copyright (C) 2000-2013, written by Shkolnik Mike, Scalabium Software
  E-Mail:  xlslib@scalabium.com
  WEB: http://www.scalabium.com/xls/xlslib.htm
}
unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, ComCtrls, Grids;

type
  TfrmMain = class(TForm)
    pcData: TPageControl;
    pnlFileName: TPanel;
    lblFileName: TLabel;
    edFileName: TEdit;
    btnLoad: TButton;
    lblURL: TLabel;
    btnAbout: TButton;
    procedure FormCreate(Sender: TObject);
    procedure btnLoadClick(Sender: TObject);
    procedure lblURLClick(Sender: TObject);
    procedure btnAboutClick(Sender: TObject);
  private
    { Private declarations }
    procedure DeletePages;
    function AddPageGrid(SheetCaption: string): TStringGrid;

    function GetXLSColID(ID: Integer): string;
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation

{$R *.DFM}
{ $ R winxp.res}

uses SMXLSLib, ShellAPI;

procedure TfrmMain.FormCreate(Sender: TObject);
begin
  edFileName.Text := ExtractFilePath(Application.ExeName) + edFileName.Text;
end;

procedure TfrmMain.btnLoadClick(Sender: TObject);
var
  xlsHandle: THandle;
  i, j, k, n: Integer;

  arrSheetTitle, arrTextCell: PChar;
  intSheetCount, intRowCount, intColCount: Integer;

  grid: TStringGrid;
begin
  DeletePages;

  {open xls-file}
  xlsHandle := XLSOpenFile(PChar(edFileName.Text));
  try
    {get the sheet count}
    intSheetCount := XLSGetSheetCount(xlsHandle);

    for i := 0 to intSheetCount-1 do
    begin
      n := XLSGetSheetNameLength(xlsHandle, i);
      {get the sheet name/colcount/rowcount for every sheet}
      GetMem(arrSheetTitle, n+1);
      try
        XLSGetSheetInfo(xlsHandle, i, arrSheetTitle, n, intRowCount, intColCount);

        {create tab and grid in PageControl for every sheet}
        grid := AddPageGrid(arrSheetTitle);
        grid.RowCount := intRowCount+1;
        grid.ColCount := intColCount+1;
      finally
        FreeMem(arrSheetTitle);
      end;

      for j := 0 to intRowCount do
        for k := 0 to intColCount do
        begin
          n := XLSGetCellValueLength(xlsHandle, i, j, k);
          if (n > 0) then
          begin
            GetMem(arrTextCell, n+1);
            try
              XLSGetCellValue(xlsHandle, i, j, k, n, arrTextCell);
              grid.Cells[k+1, j+1] := arrTextCell;
            finally
              FreeMem(arrTextCell);
            end
          end
        end;

      {fill captions for columns and rows}
      for j := 1 to grid.RowCount-1 do
        grid.Cells[0, j] := IntToStr(j);
      for k := 1 to grid.ColCount-1 do
       grid.Cells[k, 0] := GetXLSColID(k);
    end;
  finally
    {close xls-file}
    XLSCloseFile(xlsHandle);
  end;
end;

procedure TfrmMain.btnAboutClick(Sender: TObject);
begin
  XLSAboutLib
end;

procedure TfrmMain.DeletePages;
var
  i: Integer;
begin
  {destroy all tabs/grids for previous loaded wordbook}
  for i := pcData.PageCount-1 downto 0 do
    pcData.Pages[i].Free;
end;

function TfrmMain.AddPageGrid(SheetCaption: string): TStringGrid;
var
  tab: TTabSheet;
begin
  {create a tab and grid for each sheet in workbook}
  tab := TTabSheet.Create(pcData);
  tab.Caption := SheetCaption;
  tab.PageControl := pcData;

  Result := TStringGrid.Create(tab);
  Result.DefaultRowHeight := 21;
  Result.Options := [goFixedVertLine, goFixedHorzLine, goVertLine, goHorzLine, goRangeSelect, goColSizing];
  Result.Parent := tab;
  Result.Align := alClient;
end;

function TfrmMain.GetXLSColID(ID: Integer): string;
const
  ZARange = Ord('Z') - Ord('A');
var
  i: Integer;
begin
  Result:= '';
  i := ID;
  while i > 0 do
  begin
    Result := Char(Ord('A') + Pred(i) mod Succ(ZARange)) + Result;
    i := Pred(i) div Succ(ZARange);
  end
end;

procedure TfrmMain.lblURLClick(Sender: TObject);
begin
  ShellExecute(0, 'open', PChar((Sender as TLabel).Caption), nil, nil, SW_SHOWNORMAL);
end;


end.
