/* Reader Engine for Excel files (DLL edition)

  Copyright (C) 2000-2022, written by Shkolnik Mike, Scalabium Software
  E-Mail:  xlslib@scalabium.com
  WEB: http://www.scalabium.com/xls/xlslib.htm
*/
//#pragma pack(4)
#pragma comment(lib, "SMXLSLib.lib")
# include <string.h>
#include <windows.h>
 
typedef int THandle;


extern "C" void __declspec(dllexport) __cdecl XLSAboutLib(); 

//file methods
#ifdef _UNICODE
extern "C" THandle __declspec(dllexport) __cdecl XLSOpenFileW(const LPCTSTR AFileName); 
#else
extern "C" THandle __declspec(dllexport) __cdecl XLSOpenFile(const LPCTSTR AFileName); 
#endif

extern "C" void __declspec(dllexport) __cdecl XLSCloseFile(THandle AHandle); 
extern "C" int __declspec(dllexport) __cdecl XLSGetVersion(THandle AHandle); 
//extern "C" char* __declspec(dllexport) __cdecl XLSGetFileType(THandle AHandle); 
extern "C" bool __declspec(dllexport) __cdecl XLSIsEncrypted(THandle AHandle); 

//sheet methods
extern "C" int __declspec(dllexport) __cdecl XLSGetSheetCount(THandle AHandle); 
extern "C" int __declspec(dllexport) __cdecl XLSGetSheetNameLength(THandle AHandle, int SheetIndex); 
#ifdef _UNICODE
extern "C" int __declspec(dllexport) __cdecl XLSGetSheetIndexByNameW(THandle AHandle, const LPCTSTR SheetName); 
extern "C" void __declspec(dllexport) __cdecl XLSGetSheetInfoW(THandle AHandle, int SheetIndex, LPSTR &Caption, int MaxLen, int &RowCount, int &ColCount); 
extern "C" void __declspec(dllexport) __cdecl XLSGetCellValueW(THandle AHandle, int SheetIndex, int Row, int Col, int MaxLen, LPSTR &Value); 
#else
extern "C" int __declspec(dllexport) __cdecl XLSGetSheetIndexByName(THandle AHandle, const LPCTSTR SheetName); 
extern "C" void __declspec(dllexport) __cdecl XLSGetSheetInfo(THandle AHandle, int SheetIndex, LPSTR &Caption, int MaxLen, int &RowCount, int &ColCount); 
extern "C" void __declspec(dllexport) __cdecl XLSGetCellValue(THandle AHandle, int SheetIndex, int Row, int Col, int MaxLen, LPSTR &Value); 
#endif

//cell methods
extern "C" int __declspec(dllexport) __cdecl XLSGetCellType(THandle AHandle, int SheetIndex, int Row, int Col);
extern "C" int __declspec(dllexport) __cdecl XLSGetCellValueLength(THandle AHandle, int SheetIndex, int Row, int Col);
extern "C" void __declspec(dllexport) __cdecl XLSGetCellAttr(THandle AHandle, int SheetIndex, int Row, int Col, LPSTR &AFormatMask, int FormatMaxLen, LPSTR &AFontName, int FontNameMaxLen, int &AFontStyle, int &AFontSize, int &AFontColor, int &ABackground, byte &AHorAlignment, byte &AVerAlignment); 
extern "C" void __declspec(dllexport) __cdecl XLSGetRangeValues(THandle AHandle, int SheetIndex, LPSTR Range, VARIANT &Value); 

extern "C" bool __declspec(dllexport) __cdecl XLSIsCellFormula(THandle AHandle, int SheetIndex, int Row, int Col);
extern "C" void __declspec(dllexport) __cdecl XLSGetCellFormula(THandle AHandle, int SheetIndex, int Row, int Col, int MaxLen, LPSTR &Value);
extern "C" int __declspec(dllexport) __cdecl XLSGetCellFormulaLength(THandle AHandle, int SheetIndex, int Row, int Col);

//width/height
extern "C" int __declspec(dllexport) __cdecl XLSGetColumnWidth(THandle AHandle, int SheetIndex, int Col);
extern "C" int __declspec(dllexport) __cdecl XLSGetRowHeight(THandle AHandle, int SheetIndex, int Row);

//named ranges
extern "C" int __declspec(dllexport) __cdecl XLSGetNamedRangeCount(THandle AHandle); 
extern "C" void __declspec(dllexport) __cdecl XLSGetNamedRangeLength(THandle AHandle, int Index, int &NameLen, int &FormulaLen); 
#ifdef _UNICODE
extern "C" void __declspec(dllexport) __cdecl XLSGetNamedRangeInfo_W(THandle AHandle, int Index, LPSTR &Name, int NameLen, LPSTR &Formula, int FormulaLen); 
#else
extern "C" void __declspec(dllexport) __cdecl XLSGetNamedRangeInfo(THandle AHandle, int Index, LPSTR &Name, int NameLen, LPSTR &Formula, int FormulaLen); 
#endif

//save to file
extern "C" void __declspec(dllexport) __cdecl XLSConvertToCSV(const LPCTSTR XLSFileName, const LPCTSTR CSVFileName, const LPCTSTR FieldDelimiter, const LPCTSTR TextQualifier, int ASheetIndex);
extern "C" void __declspec(dllexport) __cdecl XLSConvertToHTML(const LPCTSTR XLSFileName, const LPCTSTR HTMLFileName, int ASheetIndex);
extern "C" void __declspec(dllexport) __cdecl XLSConvertToXML(const LPCTSTR XLSFileName, const LPCTSTR XMLFileName, int ASheetIndex);
extern "C" void __declspec(dllexport) __cdecl XLSConvertToExcelXML(const LPCTSTR XLSFileName, const LPCTSTR XMLFileName, int ASheetIndex);
extern "C" void __declspec(dllexport) __cdecl XLSConvertToLotus123(const LPCTSTR XLSFileName, const LPCTSTR WKSFileName, int ASheetIndex);
extern "C" void __declspec(dllexport) __cdecl XLSConvertToXLSX(const LPCTSTR XLSFileName, const LPCTSTR XLSXFileName, int ASheetIndex);

//summary information
extern "C" int __declspec(dllexport) __cdecl XLSGetSummaryInformationLength(THandle AHandle); 
extern "C" void __declspec(dllexport) __cdecl XLSGetSummaryInformation(THandle AHandle, LPSTR &Info, int MaxLen); 

//cell types, returned in XLSGetCellType
enum XLSCellType
{
  xctUnknown  = 0,
  xctEmpty    = 1,
  xctString   = 2,
  xctInteger  = 3,
  xctDecimal  = 4,
  xctDateTime = 5,
  xctBoolean  = 6,
  xctMemo     = 7,
  xctDate     = 8,
  xctTime     = 9,
};
